@@ -5,7 +5,7 @@ use warnings;
 
 use parent qw(Net::Async::Redis::Commands IO::Async::Notifier);
 
-our $VERSION = '1.000';
+our $VERSION = '1.001';
 
 =head1 NAME
 
@@ -42,6 +42,7 @@ use Log::Any qw($log);
 
 use List::Util qw(pairmap);
 
+use Net::Async::Redis::Multi;
 use Net::Async::Redis::Subscription;
 use Net::Async::Redis::Subscription::Message;
 
@@ -112,6 +113,47 @@ sub subscribe {
         })
 }
 
+=head1 METHODS - Transactions
+
+
+
+=cut
+
+=head2 multi
+
+Executes the given code in a Redis C<MULTI> transaction.
+
+This will cause each of the requests to be queued, then executed in a single atomic transaction.
+
+Example:
+
+ $redis->multi(sub {
+  my $tx = shift;
+  $tx->incr('some::key')->on_done(sub { print "Final value for incremented key was " . shift . "\n"; });
+  $tx->set('other::key => 'test data')
+ })->then(sub {
+  my ($success, $failure) = @_;
+  return Future->fail("Had $failure failures, expecting everything to succeed") if $failure;
+  print "$success succeeded\m";
+  return Future->done;
+ });
+
+=cut
+
+sub multi {
+    use Scalar::Util qw(reftype);
+    use namespace::clean qw(reftype);
+    my ($self, $code) = @_;
+    die 'Need a coderef' unless $code and reftype($code) eq 'CODE';
+    my $multi = Net::Async::Redis::Multi->new(
+        redis => $self,
+    );
+    $self->next::method
+        ->then(sub {
+            $multi->exec($code)
+        })
+}
+
 sub keys : method {
 	my ($self, $match) = @_;
 	$match //= '*';
@@ -300,6 +342,11 @@ sub ryu {
     }
 }
 
+sub future {
+    my ($self) = @_;
+    return $self->loop->new_future(@_);
+}
+
 sub protocol {
 	my ($self) = @_;
 	$self->{protocol} ||= do {
